@@ -64,6 +64,16 @@ BEGIN{
   # Disable buffering
   STDERR->autoflush(1);
   STDOUT->autoflush(1);
+
+  # NO!  Momentarily I thought it would be a Good Thing to set a standard
+  # terminal width in COLUMNS ignoring the actual terminal.  But some
+  # modules test term width autodetect by unsetting COLUMNS and would
+  # then get a (possibly) different result.
+  #
+  # So it is necessary for *every* package which probes for terminal width
+  # use robust code which won't fail even if there is no terminal
+  # (which is gross -- see Data::Dumper::Interp::_get_terminal_width)
+  ##$ENV{COLUMNS} = 80;
 }
 use POSIX ();
 use utf8;
@@ -94,12 +104,6 @@ our @EXPORT_OK = qw/$savepath $debug $silent $verbose %dvs dprint dprintf/;
 use Import::Into;
 use Data::Dumper;
 
-unless (Cwd::abs_path(__FILE__) =~ /Data-Dumper-Interp/) {
-  # unless we are testing DDI
-  #$Data::Dumper::Interp::Foldwidth = undef; # use terminal width
-  $Data::Dumper::Interp::Useqq = "controlpics:unicode";
-}
-
 use Cwd qw/getcwd abs_path/;
 use POSIX qw/INT_MAX/;
 use File::Basename qw/dirname/;
@@ -107,6 +111,14 @@ use Capture::Tiny qw/capture capture_merged tee_merged/;
 use Env qw/@PATH @PERL5LIB/;  # ties @PATH, @PERL5LIB
 use Config;
 
+BEGIN {
+  unless (Cwd::abs_path(__FILE__) =~ /Data-Dumper-Interp/) {
+    # Unless we are testing DDI
+    #$Data::Dumper::Interp::Foldwidth = undef; # use terminal width
+    $Data::Dumper::Interp::Useqq = "controlpics:unicode";
+  }
+}
+
 sub bug(@) { @_=("BUG FOUND:",@_); goto &Carp::confess }
 
 # Parse manual-testing args from @ARGV
@@ -256,10 +268,11 @@ sub run_perlscript(@) {
   #unshift @perlargs, "-MCarp=verbose" if $Carp::Verbose;
   #unshift @perlargs, "-MCarp::Always=verbose" if $Carp::Always::Verbose;
 
-  # For unknown reason some smokers running older perls die with
-  # "...undef value as a subroutine reference at site_perl/5.20.3/TAP/Harness.pm line 612
-  # So trying to see what is happening...
-  unshift @perlargs, "-MCarp::Always=verbose";
+  ##This breaks no-internals-mentioned (AUTHOR_TESTS) in Spreadsheet::Edit
+  ## For unknown reason some smokers running older perls die with
+  ## "...undef value as a subroutine reference at site_perl/5.20.3/TAP/Harness.pm line 612
+  ## So trying to see what is happening...
+  #unshift @perlargs, "-MCarp::Always=verbose";
 
   if ($^O eq "MSWin32") {
     for (my $ix=0; $ix <= $#perlargs; $ix++) {
@@ -277,7 +290,7 @@ warn "============= DUMP OF -$1$2 FILE ===========\n", "".scalar($tf->slurp_utf8
     }
     for (my $ix=0; $ix <= $#perlargs; $ix++) {
       for ($perlargs[$ix]) {
-        if (/^-\*[Ee]/) { oops "unhandled perl arg" }
+        if (/^-[eE]/ or /^-[^-CIM].*[Ee]/) { oops "unhandled perl arg '$_'" }
         s/"/\\"/g;
         if (/[\s\/"']/) {
           $_ = '"' . $_ . '"';
@@ -416,7 +429,7 @@ my $testee_top_module;
 for (my $path=path(__FILE__);
              $path ne Path::Tiny->rootdir; $path=$path->parent) {
   if (-e (my $p = $path->child("dist.ini"))) {
-    $p->slurp_utf8() =~ /^ *name *= *(\S+)/i or oops;
+    $p->slurp_utf8() =~ /^ *name *= *(\S+)/im or oops;
     ($testee_top_module = $1) =~ s/-/::/g;
     last
   }
@@ -451,13 +464,19 @@ sub verif_no_internals_mentioned($) { # croaks if references found
   s#\b(\bt_\w+).pm(\W|$)#<$1 .pm>$2#gs;
 
   my $msg;
-  if (/\b(?<hit>${testee_top_module}::[\w:]*)/) {
-    $msg = "ERROR: Log msg or traceback mentions internal package '$+{hit}'"
+  if (/\b(?<hit>${testee_top_module}::)/) {
+    $msg = "ERROR: Log msg or traceback mentions internal sub '$+{hit}'"
+      ###TEMP
+      #.dvis('\n($testee_top_module)\n')
+      #."(IN:$_)\n"
+      ;
   }
   elsif (/(?<hit>[-.\w\/]+\.pm\b)/s) {
     $msg = "ERROR: Log msg or traceback mentions non-test .pm file '$+{hit}'"
   }
   if ($msg) {
+    ###TEMP
+    #die "---XXX---\n$msg\n$_\n---YYY---\n";
     my $start = $-[1]; # offset of start of item
     my $end   = $+[1]; # offset of end+1
     substr($_,$start,0) = "HERE>>>";
@@ -809,15 +828,21 @@ sub clean_capture_output($) {
 
 sub my_capture(&) {
   my ($out, $err, @results) = &capture($_[0]);
-  return( clean_capture_output($out), clean_capture_output($err), @results );
+  $out = clean_capture_output($out);
+  $err = clean_capture_errput($err);
+  confess "my_capture: Must be called in list context to receive both stdout & err"
+    unless wantarray;
+  return( $out, $err, @results );
 }
 sub my_capture_merged(&) {
   my ($merged, @results) = &capture_merged($_[0]);
-  return( clean_capture_output($merged), @results );
+  $merged = clean_capture_output($merged);
+  return( wantarray ? ($merged, @results) : $merged );
 }
 sub my_tee_merged(&) {
   my ($merged, @results) = &tee_merged($_[0]);
-  return( clean_capture_output($merged), @results );
+  $merged = clean_capture_output($merged);
+  return( wantarray ? ($merged, @results) : $merged );
 }
 
 1;
